@@ -12,4 +12,6 @@ OBJECT_CLASSES = {
     resources.Transfers.OBJECT_NAME: resources.Transfers,
     resources.Participants.OBJECT_NAME: resources.Participants,
     resources.Time.OBJECT_NAME: resources.Time,
+    resources.WithdrawalDigitalAssetAddresses.OBJECT_NAME: resources.WithdrawalDigitalAssetAddresses,
+    resources.Withdrawals.OBJECT_NAME: resources.Withdrawals,
 }
