@@ -10,3 +10,7 @@ from zerohash.resources.time import Time
 from zerohash.resources.trades import Trades
 from zerohash.resources.trades_batch import TradesBatch
 from zerohash.resources.transfers import Transfers
+from zerohash.resources.withdrawal_digital_asset_addresses import (
+    WithdrawalDigitalAssetAddresses,
+)
+from zerohash.resources.withdrawals import Withdrawals
